==> haskell-cprng-aes-0.6.1-296-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cprng-aes
version:              0.6.1
visibility:           public
id:                   cprng-aes-0.6.1-Bqk8cQmK8COCTFEqiuhpiy
key:                  cprng-aes-0.6.1-Bqk8cQmK8COCTFEqiuhpiy
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cprng-aes
synopsis:
    Crypto Pseudo Random Number Generator using AES in counter mode.

description:
    Simple crypto pseudo-random-number-generator with really good randomness property.

    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)

    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).

category:             Cryptography
abi:                  65c828268f79620a6149b4dfd34ca891
exposed:              True
exposed-modules:      Crypto.Random.AESCtr
hidden-modules:       Crypto.Random.AESCtr.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cprng-aes-0.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cprng-aes
hs-libraries:         HScprng-aes-0.6.1-Bqk8cQmK8COCTFEqiuhpiy
depends:
    base-4.15.1.0 byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
    bytestring-0.10.12.1 cipher-aes-0.2.11-8RHtOtsjaCIGoAMR9vOsES
    crypto-random-0.0.9-7gQFhjJtH6ZCfBMBOrJKfm

haddock-interfaces:   /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html:         /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cprng-aes-0.6.1-312-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cprng-aes
version:              0.6.1
visibility:           public
id:                   cprng-aes-0.6.1-9D5TAMZ4xY9Dklh1Hj4a3z
key:                  cprng-aes-0.6.1-9D5TAMZ4xY9Dklh1Hj4a3z
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-cprng-aes
synopsis:
    Crypto Pseudo Random Number Generator using AES in counter mode.

description:
    Simple crypto pseudo-random-number-generator with really good randomness property.

    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)

    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).

category:             Cryptography
abi:                  dc5fa9de28e5e7f49a02bbf83d89f661
exposed:              True
exposed-modules:      Crypto.Random.AESCtr
hidden-modules:       Crypto.Random.AESCtr.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/cprng-aes-0.6.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cprng-aes
hs-libraries:         HScprng-aes-0.6.1-9D5TAMZ4xY9Dklh1Hj4a3z
depends:
    base-4.15.1.0 byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
    bytestring-0.10.12.1 cipher-aes-0.2.11-HAya1zfjUBU4rs3SXUs8hr
    crypto-random-0.0.9-GvetF5f2h7rHNGt5A4YC42

haddock-interfaces:   /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html:         /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
